@@ -10,7 +10,6 @@ const St = imports.gi.St;
 const PopupMenu = imports.ui.popupMenu;
 const GLib = imports.gi.GLib;
 const Cvc = imports.gi.Cvc;
-const Pango = imports.gi.Pango;
 const Tooltips = imports.ui.tooltips;
 const Main = imports.ui.main;
 const Settings = imports.ui.settings;
@@ -77,7 +76,7 @@ ControlButton.prototype = {
         this.button.can_focus = status;
         this.button.reactive = status;
     }
-}
+};
 
 function VolumeSlider(){
     this._init.apply(this, arguments);
@@ -140,7 +139,7 @@ VolumeSlider.prototype = {
 
         let volume = this._value * this.applet._volumeMax, muted;
 
-        if(this._value < .005){
+        if(this._value < 0.005){
             volume = 0;
             muted = true;
         } else {
@@ -172,7 +171,7 @@ VolumeSlider.prototype = {
     },
 
     _volumeToIcon: function(value){
-        if(value < .005)
+        if(value < 0.005)
             return this.isMic? "microphone-sensitivity-none" : "audio-volume-muted";
         let n = Math.floor(3 * value), icon;
         if(n < 1)
@@ -184,7 +183,7 @@ VolumeSlider.prototype = {
 
         return this.isMic? "microphone-sensitivity-" + icon : "audio-volume-" + icon;
     }
-}
+};
 
 function StreamMenuSection(){
     this._init.apply(this, arguments);
@@ -227,7 +226,7 @@ StreamMenuSection.prototype = {
         let slider = new VolumeSlider(applet, stream, name, iconName);
         this.addMenuItem(slider);
     }
-}
+};
 
 function Player() {
     this._init.apply(this, arguments);
@@ -243,6 +242,7 @@ Player.prototype = {
         this._busName = busname;
         this._applet = applet;
         this._name = this._busName.split('.')[3];
+        this._songLength = 0;
 
         Interfaces.getDBusProxyWithOwnerAsync(MEDIA_PLAYER_2_NAME,
                                               this._busName,
@@ -282,7 +282,7 @@ Player.prototype = {
         if (!this._prop || !this._mediaServerPlayer || !this._mediaServer)
             return;
 
-        let mainBox = new PopupMenu.PopupMenuSection;
+        let mainBox = new PopupMenu.PopupMenuSection();
         this.addMenuItem(mainBox);
 
         this.vertBox = new St.BoxLayout({ style_class: "sound-player", important: true, vertical: true });
@@ -292,8 +292,8 @@ Player.prototype = {
         let playerBox = new St.BoxLayout();
         this.playerIcon = new St.Icon({icon_type: St.IconType.SYMBOLIC, style_class: "popup-menu-icon"});
         this.playerLabel = new St.Label({y_expand: true, y_align: Clutter.ActorAlign.CENTER});
-        playerBox.add_actor(this.playerIcon, { expand: true, x_fill: false, x_align: St.Align.START });
-        playerBox.add_actor(this.playerLabel, { expand: true, x_fill: false, x_align: St.Align.START });
+        playerBox.add_actor(this.playerIcon);
+        playerBox.add_actor(this.playerLabel);
 
         if (this._mediaServer.CanRaise) {
             let btn = new ControlButton("go-up", _("Open Player"), Lang.bind(this, function(){
@@ -306,17 +306,17 @@ Player.prototype = {
                 }
                 this._applet.menu.close();
             }), true);
-            playerBox.add_actor(btn.actor, { expand: true, x_fill: false, x_align: St.Align.END });
+            playerBox.add_actor(btn.actor);
         }
         if (this._mediaServer.CanQuit) {
             let btn = new ControlButton("window-close", _("Quit Player"), Lang.bind(this, function(){
                 this._mediaServer.QuitRemote();
                 this._applet.menu.close();
             }), true);
-            playerBox.add_actor(btn.actor, { expand: true, x_fill: false, x_align: St.Align.END });
+            playerBox.add_actor(btn.actor);
         }
 
-        this.vertBox.add_actor(playerBox, {expand: false, x_fill: false});
+        this.vertBox.add_actor(playerBox);
 
         // Cover Box (art + track info)
         this._trackCover = new St.Bin({x_align: St.Align.MIDDLE});
@@ -494,7 +494,7 @@ Player.prototype = {
         this._canSeek = this._getCanSeek();
 
         if (this._songLength == 0 || position == false)
-            this._canSeek = false
+            this._canSeek = false;
     },
 
     _setPosition: function(value) {
@@ -609,7 +609,6 @@ Player.prototype = {
                 let cover_path = "";
                 if (this._trackCoverFile.match(/^http/)) {
                     this._hideCover();
-                    let cover = Gio.file_new_for_uri(decodeURIComponent(this._trackCoverFile));
                     this._trackCoverFileTmp = Gio.file_new_tmp('XXXXXX.mediaplayer-cover')[0];
                     Util.spawn_async(['wget', this._trackCoverFile, '-O', this._trackCoverFileTmp.get_path()], Lang.bind(this, this._onDownloadedCover));
                 }
@@ -796,7 +795,7 @@ Player.prototype = {
         PopupMenu.PopupMenuSection.prototype.destroy.call(this);
     }
 
-}
+};
 
 function MediaPlayerLauncher(app, menu) {
     this._init(app, menu);
@@ -814,14 +813,12 @@ MediaPlayerLauncher.prototype = {
         this.addActor(this.label);
         this._icon = app.create_icon_texture(ICON_SIZE);
         this.addActor(this._icon, { expand: false });
+        this.connect("activate", Lang.bind(this, this._onActivate));
     },
 
-    activate: function (event) {
-        this._menu.actor.hide();
+    _onActivate: function(actor, event, keepMenu) {
         this._app.activate_full(-1, event.get_time());
-        return true;
     }
-
 };
 
 function MyApplet(metadata, orientation, panel_height, instanceId) {
@@ -838,7 +835,6 @@ MyApplet.prototype = {
 
         try {
             this.metadata = metadata;
-            this.orientation = orientation;
             this.settings = new Settings.AppletSettings(this, metadata.uuid, instanceId);
             this.settings.bind("showtrack", "showtrack", this.on_settings_changed);
             this.settings.bind("middleClickAction", "middleClickAction");
@@ -941,7 +937,7 @@ MyApplet.prototype = {
             this._applet_context_menu.addMenuItem(this.mute_out_switch);
             this._applet_context_menu.addMenuItem(this.mute_in_switch);
 
-            this._applet_context_menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem);
+            this._applet_context_menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
 
             this._outputApplicationsMenu = new PopupMenu.PopupSubMenuMenuItem(_("Applications"));
             this._selectOutputDeviceItem = new PopupMenu.PopupSubMenuMenuItem(_("Output device"));
@@ -950,7 +946,7 @@ MyApplet.prototype = {
             this._outputApplicationsMenu.actor.hide();
             this._selectOutputDeviceItem.actor.hide();
 
-            this._inputSection = new PopupMenu.PopupMenuSection;
+            this._inputSection = new PopupMenu.PopupMenuSection();
             this._inputVolumeSection = new VolumeSlider(this, null, _("Microphone"), null);
             this._inputVolumeSection.connect("values-changed", Lang.bind(this, this._inputValuesChanged));
             this._selectInputDeviceItem = new PopupMenu.PopupSubMenuMenuItem(_("Input device"));
@@ -961,7 +957,7 @@ MyApplet.prototype = {
             this._selectInputDeviceItem.actor.hide();
             this._inputSection.actor.hide();
 
-            this._applet_context_menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem);
+            this._applet_context_menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
 
             this.mute_out_switch.connect('toggled', Lang.bind(this, this._toggle_out_mute));
             this.mute_in_switch.connect('toggled', Lang.bind(this, this._toggle_in_mute));
@@ -971,7 +967,8 @@ MyApplet.prototype = {
             this._volumeControlShown = false;
 
             this._showFixedElements();
-            this.updateLabelVisible();
+            this.set_show_label_in_vertical_panels(false);
+            this.set_applet_label(this._applet_label.get_text());
 
             let appsys = Cinnamon.AppSystem.get_default();
             appsys.connect("installed-changed", Lang.bind(this, this._updateLaunchPlayer));
@@ -1129,13 +1126,6 @@ MyApplet.prototype = {
         }
     },
 
-    updateLabelVisible: function() {
-        if (this.orientation == St.Side.LEFT || this.orientation == St.Side.RIGHT)
-            this.hide_applet_label(true);
-        else
-            this.hide_applet_label(false);
-    },
-
     setAppletText: function(player) {
         let title_text = "";
         if (this.showtrack && player && player._playerStatus == 'Playing') {
@@ -1145,7 +1135,6 @@ MyApplet.prototype = {
             }
         }
         this.set_applet_label(title_text);
-        this.updateLabelVisible();
     },
 
     setAppletTextIcon: function(player, icon) {
@@ -1165,7 +1154,6 @@ MyApplet.prototype = {
     },
 
     _addPlayer: function(busName, owner) {
-        let position;
         if (this._players[owner]) {
             let prevName = this._players[owner]._busName;
             // HAVE: ADDING: ACTION:
@@ -1254,7 +1242,7 @@ MyApplet.prototype = {
         //do we know already this player?
         for (let i = 0, l = this._knownPlayers.length; i < l; ++i) {
             if (this._knownPlayers[i] === entry)
-                return
+                return;
         }
         //No, save it to _knownPlayers and update player list
         this._knownPlayers.push(entry);
@@ -1274,12 +1262,12 @@ MyApplet.prototype = {
         this._updateLaunchPlayer();
 
         //between these two separators will be the player MenuSection (position 3)
-        this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem);
+        this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
         this._outputVolumeSection = new VolumeSlider(this, null, _("Volume"), null);
         this._outputVolumeSection.connect("values-changed", Lang.bind(this, this._outputValuesChanged));
 
         this.menu.addMenuItem(this._outputVolumeSection);
-        this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem);
+        this.menu.addMenuItem(new PopupMenu.PopupSeparatorMenuItem());
 
         this.menu.addSettingsAction(_("Sound Settings"), 'sound');
     },
@@ -1337,8 +1325,10 @@ MyApplet.prototype = {
             this.menu.box.remove_actor(this._players[this._activePlayer].actor);
 
         this._activePlayer = player;
-        if (this.playerControl)
+        if (this.playerControl && this._activePlayer != null) {
             this.menu.addMenuItem(this._players[player], 1);
+        }
+
         this._updatePlayerMenuItems();
     },
 
@@ -1508,11 +1498,6 @@ MyApplet.prototype = {
 
     unregisterSystrayIcons: function() {
         Main.systrayManager.unregisterId(this.metadata.uuid);
-    },
-
-    on_orientation_changed: function(orientation) {
-        this.orientation = orientation;
-        this.updateLabelVisible();
     }
 };
 
